@@ -30,11 +30,11 @@ class FileFetchJob : public KJob
 {
     Q_OBJECT
 public:
-    FileFetchJob(const QStringList& urls, QObject* parent = 0);
+    explicit FileFetchJob(const QStringList& urls, QObject* parent = nullptr);
 
     QList<QVariantMap> data() const;
 
-    virtual void start() Q_DECL_OVERRIDE;
+    void start() override;
 
 private Q_SLOTS:
     void doStart();
