@@ -33,7 +33,7 @@ namespace Baloo {
  * @brief Provides the data for the MetaDataWidget.
  *
  * The default implementation provides all meta data
- * that are available due to Nepomuk. If custom
+ * that are available due to Baloo. If custom
  * meta data should be added, the method KFileMetaDataProvider::loadData()
  * must be overwritten.
  *
@@ -44,8 +44,8 @@ class FileMetaDataProvider : public QObject
     Q_OBJECT
 
 public:
-    explicit FileMetaDataProvider(QObject* parent = 0);
-    virtual ~FileMetaDataProvider();
+    explicit FileMetaDataProvider(QObject* parent = nullptr);
+    ~FileMetaDataProvider() override;
 
     /**
      * Sets the items, where the meta data should be
@@ -137,7 +137,7 @@ private:
     void insertFilesListBasicData();
     
     /**
-     * Checks for the existance of \p uri in \p allProperties, and accordingly
+     * Checks for the existence of \p uri in \p allProperties, and accordingly
      * inserts the total integer value of that property in m_data. On completion
      * it removes \p uri from \p allProperties
      */
