@@ -25,17 +25,17 @@
 #include <KConfigGui/KWindowConfig>
 #include <KSharedConfig>
 
-#include <QtCore/QEvent>
-#include <QtCore/QPointer>
-#include <QtWidgets/QLabel>
-#include <QtWidgets/QTextEdit>
-#include <QtWidgets/QVBoxLayout>
+#include <QEvent>
+#include <QPointer>
+#include <QLabel>
+#include <QTextEdit>
+#include <QVBoxLayout>
 
 KCommentWidget::KCommentWidget(QWidget* parent) :
     QWidget(parent),
     m_readOnly(false),
-    m_label(0),
-    m_sizeHintHelper(0),
+    m_label(nullptr),
+    m_sizeHintHelper(nullptr),
     m_comment()
 {
     m_label = new QLabel(this);
@@ -126,7 +126,7 @@ void KCommentWidget::slotLinkActivated(const QString& link)
 
     if (dialog->exec() == QDialog::Accepted) {
         const QString oldText = m_comment;
-        if (dialog != 0) {
+        if (dialog != nullptr) {
             setText(dialog->getCommentText());
         }
         if (oldText != m_comment) {
@@ -134,9 +134,9 @@ void KCommentWidget::slotLinkActivated(const QString& link)
         }
     }
 
-    if (dialog != 0) {
+    if (dialog != nullptr) {
         KWindowConfig::saveWindowSize(dialog->windowHandle(), dialogConfig);
         delete dialog;
-        dialog = 0;
+        dialog = nullptr;
     }
 }
