@@ -18,17 +18,17 @@
 #ifndef KEDIT_TAGS_DIALOG_H
 #define KEDIT_TAGS_DIALOG_H
 
-#include <QtWidgets/QDialog>
+#include <QDialog>
 
 class QLineEdit;
 class KJob;
-class QListWidget;
-class QListWidgetItem;
+class QTreeWidget;
+class QTreeWidgetItem;
 class QPushButton;
 class QTimer;
 
 /**
- * @brief Dialog to edit a list of Nepomuk tags.
+ * @brief Dialog to edit a list of Baloo tags.
  *
  * It is possible for the user to add existing tags,
  * create new tags or to remove tags.
@@ -40,10 +40,10 @@ class KEditTagsDialog : public QDialog
     Q_OBJECT
 
 public:
-    KEditTagsDialog(const QStringList& tags,
-                    QWidget* parent = 0);
+    explicit KEditTagsDialog(const QStringList& tags,
+                             QWidget* parent = nullptr);
 
-    virtual ~KEditTagsDialog();
+    ~KEditTagsDialog() override;
 
     QStringList tags() const;
 
@@ -52,19 +52,19 @@ private Q_SLOTS:
     void slotAcceptedButtonClicked();
 
 
-    void slotTagsLoaded(KJob* job);
+    void slotItemActivated(const QTreeWidgetItem* item, int column);
 
 private:
-    void loadTags();
-    void removeNewTagItem();
+    void loadTagWidget();
+    void modifyTagWidget(const QString& tag);
 
 private:
+    QHash<QString, QTreeWidgetItem*> m_allTagTreeItems;
     QStringList m_tags;
     QStringList m_allTags;
+    QString m_newTag;
 
-    QListWidget* m_tagsList;
-    QListWidgetItem* m_newTagItem;
-    QListWidgetItem* m_autoCheckedItem;
+    QTreeWidget* m_tagTree;
     QLineEdit* m_newTagEdit;
 };
 
