@@ -2,7 +2,7 @@
     <one line to give the library's name and an idea of what it does.>
     Copyright (C) 2012  Vishesh Handa <me@vhanda.in>
 
-    Adapated from KFileMetadataWidget
+    Adapted from KFileMetadataWidget
     Copyright (C) 2008 by Sebastian Trueg <trueg@kde.org>
     Copyright (C) 2009-2010 by Peter Penz <peter.penz@gmx.at>
 
@@ -41,7 +41,7 @@ MetadataFilter::~MetadataFilter()
 
 void MetadataFilter::initMetaInformationSettings()
 {
-    const int currentVersion = 6; // increase version, if the blacklist of disabled
+    const int currentVersion = 9; // increase version, if the blacklist of disabled
     // properties should be updated
 
     KConfig config("baloofileinformationrc", KConfig::NoGlobals);
@@ -84,13 +84,12 @@ void MetadataFilter::initMetaInformationSettings()
             "Exif.Image.DateTime",
             "Exif.Image.Orientation",
             "kfileitem#owner",
+            "kfileitem#group",
             "kfileitem#permissions",
-            "kfileitem#modified",
-            "originUrl",
-            0 // mandatory last entry
+            nullptr // mandatory last entry
         };
 
-        for (int i = 0; disabledProperties[i] != 0; ++i) {
+        for (int i = 0; disabledProperties[i] != nullptr; ++i) {
             settings.writeEntry(disabledProperties[i], false);
         }
 
