@@ -27,11 +27,11 @@
 
 #include <KFileMetaData/UserMetaData>
 
-#include <QtWidgets/QLabel>
-#include <QtCore/QCollator>
-#include <QtCore/QTime>
-#include <QtCore/QUrl>
-#include <QtCore/QLocale>
+#include <QLabel>
+#include <QCollator>
+#include <QTime>
+#include <QUrl>
+#include <QLocale>
 
 #include <KJob>
 #include <KFormat>
@@ -65,6 +65,7 @@ WidgetFactory::WidgetFactory(QObject* parent)
     : QObject(parent)
     , m_readOnly( false )
     , m_noLinks( false )
+    , m_dateFormat(QLocale::LongFormat)
 {
 }
 
@@ -99,7 +100,7 @@ static QString toString(const QVariant& value)
 
 QWidget* WidgetFactory::createWidget(const QString& prop, const QVariant& value, QWidget* parent)
 {
-    QWidget* widget = 0;
+    QWidget* widget = nullptr;
 
     if (prop == QLatin1String("rating")) {
         widget = createRatingWidget( value.toInt(), parent );
@@ -135,14 +136,13 @@ QWidget* WidgetFactory::createWidget(const QString& prop, const QVariant& value,
             }
         } else {
             // Check if Date/DateTime
-
             QDateTime dt = QDateTime::fromString(value.toString(), Qt::ISODate);
             if (dt.isValid()) {
                 QTime time = dt.time();
                 if (!time.hour() && !time.minute() && !time.second()){
-                    valueString = form.formatRelativeDate(dt.date(), QLocale::LongFormat);
+                    valueString = form.formatRelativeDate(dt.date(), m_dateFormat);
                 } else {
-                    valueString = form.formatRelativeDateTime(dt, QLocale::LongFormat);
+                    valueString = form.formatRelativeDateTime(dt, m_dateFormat);
                 }
             }
             else {
@@ -213,8 +213,8 @@ QWidget* WidgetFactory::createRatingWidget(int rating, QWidget* parent)
 class ValueWidget : public QLabel
 {
 public:
-    explicit ValueWidget(QWidget* parent = 0);
-    virtual QSize sizeHint() const Q_DECL_OVERRIDE;
+    explicit ValueWidget(QWidget* parent = nullptr);
+    QSize sizeHint() const override;
 };
 
 ValueWidget::ValueWidget(QWidget* parent) :
@@ -329,3 +329,13 @@ void WidgetFactory::setItems(const QStringList& items)
     m_items = items;
 }
 
+Baloo::DateFormats WidgetFactory::dateFormat() const
+{
+    return static_cast<Baloo::DateFormats>(m_dateFormat);
+}
+
+void Baloo::WidgetFactory::setDateFormat(const Baloo::DateFormats format)
+{
+    m_dateFormat = static_cast<QLocale::FormatType>(format);
+}
+
