@@ -1,5 +1,5 @@
 /*
-   This file is part of the Nepomuk KDE project.
+   This file is part of the Baloo KDE project.
    Copyright (C) 2010 Sebastian Trueg <trueg@kde.org>
 
    This library is free software; you can redistribute it and/or
@@ -20,8 +20,8 @@
 */
 #include "tagwidgettest.h"
 
-#include <QtWidgets/QApplication>
-#include <QtCore/QCoreApplication>
+#include <QApplication>
+#include <QCoreApplication>
 
 int main( int argc, char** argv )
 {
