@@ -1,5 +1,5 @@
 /*
-   This file is part of the Nepomuk KDE project.
+   This file is part of the Baloo KDE project.
    Copyright (C) 2010 Sebastian Trueg <trueg@kde.org>
 
    This library is free software; you can redistribute it and/or
@@ -21,9 +21,9 @@
 #include "tagwidgettest.h"
 #include "tagwidget.h"
 
-#include <QtWidgets/QVBoxLayout>
-#include <QtWidgets/QCheckBox>
-#include <QtCore/QDebug>
+#include <QVBoxLayout>
+#include <QCheckBox>
+#include <QDebug>
 
 TagWidgetTest::TagWidgetTest()
     : QWidget()
